@@ -54,8 +54,7 @@ class CookiesMiddleware:
     ) -> None:
         for cookie in cookies:
             cookie_domain = cookie.domain
-            if cookie_domain.startswith("."):
-                cookie_domain = cookie_domain[1:]
+            cookie_domain = cookie_domain.removeprefix(".")
 
             hostname = urlparse_cached(request).hostname
             assert hostname is not None
@@ -131,25 +130,26 @@ class CookiesMiddleware:
         decoded = {}
         flags = set()
         for key in ("name", "value", "path", "domain"):
-            if cookie.get(key) is None:
+            value = cookie.get(key)
+            if value is None:
                 if key in ("name", "value"):
                     msg = f"Invalid cookie found in request {request}: {cookie} ('{key}' is missing)"
                     logger.warning(msg)
                     return None
                 continue
-            # https://github.com/python/mypy/issues/7178, https://github.com/python/mypy/issues/9168
-            if isinstance(cookie[key], (bool, float, int, str)):  # type: ignore[literal-required]
-                decoded[key] = str(cookie[key])  # type: ignore[literal-required]
+            if isinstance(value, (bool, float, int, str)):
+                decoded[key] = str(value)
             else:
+                assert isinstance(value, bytes)
                 try:
-                    decoded[key] = cookie[key].decode("utf8")  # type: ignore[literal-required]
+                    decoded[key] = value.decode("utf8")
                 except UnicodeDecodeError:
                     logger.warning(
                         "Non UTF-8 encoded cookie found in request %s: %s",
                         request,
                         cookie,
                     )
-                    decoded[key] = cookie[key].decode("latin1", errors="replace")  # type: ignore[literal-required]
+                    decoded[key] = value.decode("latin1", errors="replace")
         for flag in ("secure",):
             value = cookie.get(flag, _UNSET)
             if value is _UNSET or not value:
